@@ -64,11 +64,11 @@ add_menu_action_infos (DhApp *app)
                 { "win.find", NULL, N_("_Find"), "<Control>f",
                   N_("Find in current page") },
                 { "win.zoom-in", NULL, N_("_Larger Text"), NULL,
-                  N_("Zoom in") },
+                  N_("Larger text") },
                 { "win.zoom-out", NULL, N_("S_maller Text"), "<Control>minus",
-                  N_("Zoom out") },
+                  N_("Smaller text") },
                 { "win.zoom-default", NULL, N_("_Normal Size"), "<Control>0",
-                  N_("Reset zoom") },
+                  N_("Normal size") },
                 { NULL }
         };
 
@@ -109,7 +109,7 @@ add_other_action_infos (DhApp *app)
         const AmtkActionInfoEntry entries[] = {
                 /* action, icon, label, accel, tooltip */
                 { "win.new-tab", NULL, NULL, "<Control>t", N_("Open a new tab") },
-                { "win.close", NULL, NULL, "<Control>w", N_("Close the current window") },
+                { "win.close-tab", NULL, NULL, "<Control>w", N_("Close the current tab") },
                 { "win.go-back", NULL, NULL, NULL, N_("Go back") },
                 { "win.go-forward", NULL, NULL, NULL, N_("Go forward") },
                 { "win.focus-search", NULL, NULL, NULL, N_("Focus global search") },
