@@ -48,8 +48,6 @@ typedef struct {
         GtkButton *search_prev_button;
         GtkButton *search_next_button;
         GtkNotebook *notebook;
-
-        DhLink *selected_link;
 } DhWindowPrivate;
 
 static void open_new_tab (DhWindow    *window,
@@ -58,16 +56,6 @@ static void open_new_tab (DhWindow    *window,
 
 G_DEFINE_TYPE_WITH_PRIVATE (DhWindow, dh_window, GTK_TYPE_APPLICATION_WINDOW);
 
-static void
-dh_window_dispose (GObject *object)
-{
-        DhWindowPrivate *priv = dh_window_get_instance_private (DH_WINDOW (object));
-
-        g_clear_pointer (&priv->selected_link, (GDestroyNotify) dh_link_unref);
-
-        G_OBJECT_CLASS (dh_window_parent_class)->dispose (object);
-}
-
 static gboolean
 dh_window_delete_event (GtkWidget   *widget,
                         GdkEventAny *event)
@@ -87,11 +75,8 @@ dh_window_delete_event (GtkWidget   *widget,
 static void
 dh_window_class_init (DhWindowClass *klass)
 {
-        GObjectClass *object_class = G_OBJECT_CLASS (klass);
         GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-        object_class->dispose = dh_window_dispose;
-
         widget_class->delete_event = dh_window_delete_event;
 
         /* Bind class to template */
@@ -271,19 +256,14 @@ print_cb (GSimpleAction *action,
 }
 
 static void
-close_cb (GSimpleAction *action,
-          GVariant      *parameter,
-          gpointer       user_data)
+close_tab_cb (GSimpleAction *action,
+              GVariant      *parameter,
+              gpointer       user_data)
 {
         DhWindow *window = DH_WINDOW (user_data);
         DhWindowPrivate *priv = dh_window_get_instance_private (window);
         gint page_num;
 
-        /* FIXME: the code here closes the current *tab*, but in the
-         * AmtkActionInfo it is documented as "Close the current window". Look
-         * for example at what gedit does, or other GNOME apps with a
-         * GtkNotebook plus Ctrl+W shortcut, and do the same.
-         */
         page_num = gtk_notebook_get_current_page (priv->notebook);
         gtk_notebook_remove_page (priv->notebook, page_num);
 }
@@ -302,13 +282,17 @@ copy_cb (GSimpleAction *action,
         if (GTK_IS_EDITABLE (widget)) {
                 gtk_editable_copy_clipboard (GTK_EDITABLE (widget));
         } else if (GTK_IS_TREE_VIEW (widget) &&
-                   gtk_widget_is_ancestor (widget, GTK_WIDGET (priv->sidebar)) &&
-                   priv->selected_link != NULL) {
-                GtkClipboard *clipboard;
-                clipboard = gtk_widget_get_clipboard (widget, GDK_SELECTION_CLIPBOARD);
-                gtk_clipboard_set_text (clipboard,
-                                        dh_link_get_name (priv->selected_link),
-                                        -1);
+                   gtk_widget_is_ancestor (widget, GTK_WIDGET (priv->sidebar))) {
+                DhLink *link;
+
+                link = dh_sidebar_get_selected_link (priv->sidebar);
+                if (link != NULL) {
+                        GtkClipboard *clipboard;
+
+                        clipboard = gtk_widget_get_clipboard (widget, GDK_SELECTION_CLIPBOARD);
+                        gtk_clipboard_set_text (clipboard, dh_link_get_name (link), -1);
+                        dh_link_unref (link);
+                }
         } else {
                 DhWebView *web_view;
 
@@ -440,7 +424,7 @@ shortcuts_window_cb (GSimpleAction *action,
         gtk_container_add (group, amtk_factory_create_shortcut (factory, "win.go-back"));
         gtk_container_add (group, amtk_factory_create_shortcut (factory, "win.go-forward"));
         gtk_container_add (group, amtk_factory_create_shortcut (factory, "win.print"));
-        gtk_container_add (group, amtk_factory_create_shortcut (factory, "win.close"));
+        gtk_container_add (group, amtk_factory_create_shortcut (factory, "win.close-tab"));
         gtk_container_add (group, amtk_factory_create_shortcut (factory, "app.quit"));
         gtk_container_add (section, GTK_WIDGET (group));
 
@@ -470,7 +454,7 @@ add_actions (DhWindow *window)
                 { "prev-tab", prev_tab_cb },
                 { "go-to-tab", go_to_tab_cb, "q" },
                 { "print", print_cb },
-                { "close", close_cb },
+                { "close-tab", close_tab_cb },
 
                 /* Edit */
                 { "copy", copy_cb },
@@ -602,40 +586,14 @@ set_window_menu (DhWindow *window)
         g_object_unref (window_menu);
 }
 
-static void
-settings_fonts_changed_cb (DhSettingsApp *settings,
-                           const gchar   *font_name_fixed,
-                           const gchar   *font_name_variable,
-                           DhWindow      *window)
-{
-        DhWindowPrivate *priv = dh_window_get_instance_private (window);
-        gint n_pages;
-        gint page_num;
-
-        n_pages = gtk_notebook_get_n_pages (priv->notebook);
-
-        for (page_num = 0; page_num < n_pages; page_num++) {
-                DhTab *tab;
-                WebKitWebView *web_view;
-
-                tab = DH_TAB (gtk_notebook_get_nth_page (priv->notebook, page_num));
-                web_view = WEBKIT_WEB_VIEW (dh_tab_get_web_view (tab));
-                dh_util_view_set_font (web_view, font_name_fixed, font_name_variable);
-        }
-}
-
 static void
 sidebar_link_selected_cb (DhSidebar *sidebar,
                           DhLink    *link,
                           DhWindow  *window)
 {
-        DhWindowPrivate *priv = dh_window_get_instance_private (window);
         gchar *uri;
         DhWebView *web_view;
 
-        g_clear_pointer (&priv->selected_link, (GDestroyNotify) dh_link_unref);
-        priv->selected_link = dh_link_ref (link);
-
         uri = dh_link_get_uri (link);
         if (uri == NULL)
                 return;
@@ -647,6 +605,28 @@ sidebar_link_selected_cb (DhSidebar *sidebar,
         g_free (uri);
 }
 
+static void
+sync_active_web_view_uri_to_sidebar (DhWindow *window)
+{
+        DhWindowPrivate *priv = dh_window_get_instance_private (window);
+        DhWebView *web_view;
+        const gchar *uri = NULL;
+
+        g_signal_handlers_block_by_func (priv->sidebar,
+                                         sidebar_link_selected_cb,
+                                         window);
+
+        web_view = get_active_web_view (window);
+        if (web_view != NULL)
+                uri = webkit_web_view_get_uri (WEBKIT_WEB_VIEW (web_view));
+        if (uri != NULL)
+                dh_sidebar_select_uri (priv->sidebar, uri);
+
+        g_signal_handlers_unblock_by_func (priv->sidebar,
+                                           sidebar_link_selected_cb,
+                                           window);
+}
+
 static void
 update_search_in_web_view (DhWindow  *window,
                            DhWebView *view)
@@ -801,24 +781,11 @@ notebook_switch_page_after_cb (GtkNotebook *notebook,
                                guint        new_page_num,
                                DhWindow    *window)
 {
-        DhWindowPrivate *priv = dh_window_get_instance_private (window);
-
         update_window_title (window);
         update_zoom_actions_sensitivity (window);
         update_back_forward_actions_sensitivity (window);
         update_search_in_active_web_view (window);
-
-        if (new_page != NULL) {
-                DhWebView *web_view;
-                const gchar *uri;
-
-                web_view = dh_tab_get_web_view (DH_TAB (new_page));
-
-                /* Sync the book tree */
-                uri = webkit_web_view_get_uri (WEBKIT_WEB_VIEW (web_view));
-                if (uri != NULL)
-                        dh_sidebar_select_uri (priv->sidebar, uri);
-        }
+        sync_active_web_view_uri_to_sidebar (window);
 }
 
 static void
@@ -834,12 +801,6 @@ dh_window_init (DhWindow *window)
         set_window_menu (window);
 
         settings = dh_settings_app_get_singleton ();
-        g_signal_connect_object (settings,
-                                 "fonts-changed",
-                                 G_CALLBACK (settings_fonts_changed_cb),
-                                 window,
-                                 0);
-
         paned_settings = dh_settings_app_peek_paned_settings (settings);
         g_settings_bind (paned_settings, "position",
                          priv->hpaned, "position",
@@ -930,33 +891,6 @@ web_view_zoom_level_notify_cb (DhWebView  *web_view,
                 update_zoom_actions_sensitivity (window);
 }
 
-/* FIXME: connect to this signal on the whole DhWindow widget instead? And call
- * webkit_web_view_go_back/forward() on the active web view. Because when the
- * WebKitWebView doesn't have the focus, currently this callback is not called.
- */
-static gboolean
-web_view_button_press_event_cb (WebKitWebView  *web_view,
-                                GdkEventButton *event,
-                                DhWindow       *window)
-{
-        switch (event->button) {
-                /* Some mice emit button presses when the scroll wheel is tilted
-                 * to the side. Web browsers use them to navigate in history.
-                 */
-                case 8:
-                        webkit_web_view_go_back (web_view);
-                        return GDK_EVENT_STOP;
-                case 9:
-                        webkit_web_view_go_forward (web_view);
-                        return GDK_EVENT_STOP;
-
-                default:
-                        break;
-        }
-
-        return GDK_EVENT_PROPAGATE;
-}
-
 static gchar *
 find_equivalent_local_uri (const gchar *uri)
 {
@@ -964,7 +898,7 @@ find_equivalent_local_uri (const gchar *uri)
         guint n_components;
         const gchar *book_id;
         const gchar *relative_url;
-        DhBookManager *book_manager;
+        DhBookList *book_list;
         GList *books;
         GList *book_node;
         gchar *local_uri = NULL;
@@ -989,8 +923,8 @@ find_equivalent_local_uri (const gchar *uri)
                 goto out;
         }
 
-        book_manager = dh_book_manager_get_singleton ();
-        books = dh_book_manager_get_books (book_manager);
+        book_list = dh_book_list_get_default ();
+        books = dh_book_list_get_books (book_list);
 
         for (book_node = books; book_node != NULL; book_node = book_node->next) {
                 DhBook *cur_book = DH_BOOK (book_node->data);
@@ -1023,7 +957,7 @@ web_view_decide_policy_cb (WebKitWebView            *web_view,
                            WebKitPolicyDecisionType  type,
                            DhWindow                 *window)
 {
-        const char *uri;
+        const gchar *uri;
         WebKitNavigationPolicyDecision *navigation_decision;
         WebKitNavigationAction *navigation_action;
         gchar *local_uri;
@@ -1036,6 +970,7 @@ web_view_decide_policy_cb (WebKitWebView            *web_view,
         navigation_decision = WEBKIT_NAVIGATION_POLICY_DECISION (policy_decision);
         navigation_action = webkit_navigation_policy_decision_get_navigation_action (navigation_decision);
         uri = webkit_uri_request_get_uri (webkit_navigation_action_get_request (navigation_action));
+        g_return_val_if_fail (uri != NULL, GDK_EVENT_PROPAGATE);
 
         /* middle click or ctrl-click -> new tab */
         button = webkit_navigation_action_get_mouse_button (navigation_action);
@@ -1046,21 +981,30 @@ web_view_decide_policy_cb (WebKitWebView            *web_view,
                 return GDK_EVENT_STOP;
         }
 
-        if (g_str_equal (uri, "about:blank")) {
+        if (g_str_equal (uri, "about:blank"))
                 return GDK_EVENT_PROPAGATE;
-        }
 
         local_uri = find_equivalent_local_uri (uri);
         if (local_uri != NULL) {
                 webkit_policy_decision_ignore (policy_decision);
-                _dh_window_display_uri (window, local_uri);
+                webkit_web_view_load_uri (web_view, local_uri);
                 g_free (local_uri);
                 return GDK_EVENT_STOP;
         }
 
         if (!g_str_has_prefix (uri, "file://")) {
+                GError *error = NULL;
+
                 webkit_policy_decision_ignore (policy_decision);
-                gtk_show_uri_on_window (GTK_WINDOW (window), uri, GDK_CURRENT_TIME, NULL);
+                gtk_show_uri_on_window (GTK_WINDOW (window), uri, GDK_CURRENT_TIME, &error);
+
+                if (error != NULL) {
+                        g_warning ("Error when opening URI “%s” externally: %s",
+                                   uri,
+                                   error->message);
+                        g_clear_error (&error);
+                }
+
                 return GDK_EVENT_STOP;
         }
 
@@ -1068,17 +1012,13 @@ web_view_decide_policy_cb (WebKitWebView            *web_view,
 }
 
 static void
-web_view_load_changed_cb (WebKitWebView   *web_view,
+web_view_load_changed_cb (DhWebView       *web_view,
                           WebKitLoadEvent  load_event,
                           DhWindow        *window)
 {
-        DhWindowPrivate *priv = dh_window_get_instance_private (window);
-
-        if (load_event == WEBKIT_LOAD_COMMITTED) {
-                const gchar *uri;
-
-                uri = webkit_web_view_get_uri (web_view);
-                dh_sidebar_select_uri (priv->sidebar, uri);
+        if (load_event == WEBKIT_LOAD_COMMITTED &&
+            web_view == get_active_web_view (window)) {
+                sync_active_web_view_uri_to_sidebar (window);
         }
 }
 
@@ -1090,9 +1030,6 @@ open_new_tab (DhWindow    *window,
         DhWindowPrivate *priv = dh_window_get_instance_private (window);
         DhTab *tab;
         DhWebView *web_view;
-        DhSettingsApp *settings;
-        gchar *font_fixed = NULL;
-        gchar *font_variable = NULL;
         GtkWidget *label;
         gint page_num;
         WebKitBackForwardList *back_forward_list;
@@ -1102,13 +1039,6 @@ open_new_tab (DhWindow    *window,
 
         web_view = dh_tab_get_web_view (tab);
 
-        /* Set font */
-        settings = dh_settings_app_get_singleton ();
-        dh_settings_app_get_selected_fonts (settings, &font_fixed, &font_variable);
-        dh_util_view_set_font (WEBKIT_WEB_VIEW (web_view), font_fixed, font_variable);
-        g_free (font_fixed);
-        g_free (font_variable);
-
         g_signal_connect (web_view,
                           "notify::title",
                           G_CALLBACK (web_view_title_notify_cb),
@@ -1119,11 +1049,6 @@ open_new_tab (DhWindow    *window,
                           G_CALLBACK (web_view_zoom_level_notify_cb),
                           window);
 
-        g_signal_connect (web_view,
-                          "button-press-event",
-                          G_CALLBACK (web_view_button_press_event_cb),
-                          window);
-
         g_signal_connect (web_view,
                           "decide-policy",
                           G_CALLBACK (web_view_decide_policy_cb),
@@ -1201,18 +1126,14 @@ void
 _dh_window_display_uri (DhWindow    *window,
                         const gchar *uri)
 {
-        DhWindowPrivate *priv;
         DhWebView *web_view;
 
         g_return_if_fail (DH_IS_WINDOW (window));
         g_return_if_fail (uri != NULL);
 
-        priv = dh_window_get_instance_private (window);
-
         web_view = get_active_web_view (window);
         if (web_view == NULL)
                 return;
 
         webkit_web_view_load_uri (WEBKIT_WEB_VIEW (web_view), uri);
-        dh_sidebar_select_uri (priv->sidebar, uri);
 }
